package com.dsic.gj_erp.controller.sy;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.dsic.gj_erp.bean.ResultBean;
import com.dsic.gj_erp.bean.sy.SyDictItem;
import com.dsic.gj_erp.service.sy.SyDictItemService;
import com.dsic.gj_erp.util.CacheConstant;
import org.apache.commons.lang3.StringUtils;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author xhj
 * @since 2021-03-16
 */
@RestController
@RequestMapping(value = "/api/sy/dict")
public class SyDictItemController {

    @Resource
    SyDictItemService syDictItemService;

    @PostMapping(value = "/getList")
    public ResultBean getList(@RequestBody Map<String, Object> params) {
        QueryWrapper<SyDictItem> queryWrapper = new QueryWrapper<SyDictItem>();
        if (!StringUtils.isBlank((String)params.get("name"))){
            queryWrapper.eq("bmlb",params.get("name"));
        }
        return  new  ResultBean(syDictItemService.list(queryWrapper));
    }

    /**
     * 获取以dictCode分组的字典数据
     */
    @GetMapping("mapList")
    public ResultBean<?> mapList(){
        List<SyDictItem> list=syDictItemService.list();
        Map<String,List<SyDictItem>> map=list.stream()
                .collect(Collectors.groupingBy(SyDictItem::getDictCode));
        return new ResultBean<>(map);
    }

    @PostMapping(value = "/add")
    @CacheEvict(value= CacheConstant.SYS_DICT_CACHE, allEntries=true)
    public ResultBean getList(@RequestBody List<SyDictItem> syDictItem) {
        return  new  ResultBean(syDictItemService.saveBatch(syDictItem));
    }

    @PostMapping(value = "/del")
    @CacheEvict(value= CacheConstant.SYS_DICT_CACHE, allEntries=true)
    public ResultBean del(@RequestBody List<SyDictItem> delArr) {
        for (SyDictItem syDictItem : delArr) {
            syDictItemService.remove(new QueryWrapper<SyDictItem>()
                    .eq("bmlb",syDictItem.getDictCode())
                    .eq("bm",syDictItem.getItemValue()));
        }
       return  new  ResultBean();
    }

    @PostMapping(value = "/update")
    @CacheEvict(value=CacheConstant.SYS_DICT_CACHE, allEntries=true)
    public ResultBean update(@RequestBody List<SyDictItem> syDictItem) {
        syDictItemService.updateBatchById(syDictItem);
        return  new  ResultBean();
    }

    @PostMapping("/getbycode")
    public ResultBean getByCode(@RequestBody SyDictItem syDictItem){
        return new ResultBean(this.syDictItemService.getByCode(syDictItem));
    }

    /**
     * 根据dictCode查询,itemCode右模糊查询
     */
    @PostMapping("/getByDictCodeWithItemCodeRightLike")
    public ResultBean getByDictCodeWithItemCodeRightLike(@RequestBody SyDictItem syDictItem){
        List<SyDictItem> list=this.syDictItemService.list(new QueryWrapper<SyDictItem>()
                .eq("dict_code",syDictItem.getDictCode())
                .likeRight("item_code",syDictItem.getItemCode()));
        return new ResultBean(list);
    }

}

